@@ -20,8 +20,19 @@ test_that("garch1c1 related functions work ok", {
     a <- sim_garch1c1(a_mo, n = 100, n.start = 100, seed = 1234)
     a_pred <- predict(a_mo, n.ahead = 5, Nsim = 100, eps = a$eps, sigmasq = a$h, seed = 1235)
 
-    expect_equal_to_reference(a, "a.RDS")
-    expect_equal_to_reference(a_pred, "a_pred.RDS")
+    ## 2019-03-13 deal with change in RNG in R-devel (for 2.6.0), see email from Kurt Hornik in Org/
+    ##        I couldn't make his suggestion work.
+    ## TODO: maybe it would be better to just load 'a' from a saved version.
+    if(getRversion() < "3.6.0"){
+        a_saved <- "a_before_6.0.RDS"
+        a_pred_saved <- "a_pred_before_6.0.RDS"
+    }else{
+        a_saved <- "a.RDS"
+        a_pred_saved <- "a_pred.RDS"
+    }
+
+    expect_equal_to_reference(a, a_saved)
+    expect_equal_to_reference(a_pred, a_pred_saved)
 
 
     expect_equal(.rgen(NULL), .dist$norm$r)
